package com.test.jdbc;

import java.sql.Connection;
import java.sql.DriverManager;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.sql.Statement;

public class TestJdbc {

	public static void main(String[] args) {
		if(args.length != 3) {
			usage();
			System.exit(1);
		}
		execute(args[0], args[1], Integer.valueOf(args[2]));
	}

	private static void usage() {
		System.out.println("Usage: " + TestJdbc.class.getCanonicalName() + " <connectString> <command> <number of executions>");
	}

	private static void execute(String connectString, String sqlString, int n) {
		loadDriver();
		Connection connection = createConnection(connectString);
		try {
			Statement statement = connection.createStatement();
			do {
				if(!statement.execute(sqlString)) {
					throw new RuntimeException("Unable to execute: " + sqlString);
				}
				handleResult(statement);
			} while(--n != 0);
		} catch(SQLException exc) {
			throw new RuntimeException("Error executing command: " + exc.getMessage(), exc);
		}
	}

	private static void handleResult(Statement statement) throws SQLException {
		ResultSet res = statement.getResultSet();
		try {
			while(res.next()) {
				// TODO: simulate application behavior?
			}
		} finally {
			res.close();
		}
	}

	private static Connection createConnection(String connectString) {			
		try {
			Connection connection = DriverManager.getConnection(connectString);
			return connection;
		} catch (SQLException e) {
			throw new RuntimeException("Error connecting using connect string: " + connectString, e);
		}
	}


	private static void loadDriver() {
		try {
			Class.forName("org.gjt.mm.mysql.Driver");
		} catch (ClassNotFoundException e) {
			throw new RuntimeException("Driver class not found: " + e.getMessage(),e);
		}
	}
}
